@@ -1,5 +1,5 @@
 <?php // Maps AD LDAP to Claims from http://msdn.microsoft.com/en-us/library/hh159803.aspx
-$attributemap = array(
+$attributemap = [
     'c'               => 'http://schemas.xmlsoap.org/ws/2005/05/identity/claims/country',
     'givenName'       => 'http://schemas.xmlsoap.org/ws/2005/05/identity/claims/givenname',
     'mail'            => 'http://schemas.xmlsoap.org/ws/2005/05/identity/claims/emailaddress',
@@ -10,4 +10,4 @@ $attributemap = array(
     'st'              => 'http://schemas.xmlsoap.org/ws/2005/05/identity/claims/stateorprovince',
     'streetaddress'   => 'http://schemas.xmlsoap.org/ws/2005/05/identity/claims/streetaddress',
     'telephonenumber' => 'http://schemas.xmlsoap.org/ws/2005/05/identity/claims/otherphone',
-);
+];
