@@ -2,8 +2,8 @@
 <?php
 $baseDir = dirname(dirname(__FILE__));
 
-require_once $baseDir.DIRECTORY_SEPARATOR.'lib'.DIRECTORY_SEPARATOR.'_autoload.php';
-require_once \SimpleSAML\Utils\Config::getConfigDir().DIRECTORY_SEPARATOR.'config.php';
+require_once $baseDir . DIRECTORY_SEPARATOR . 'lib' . DIRECTORY_SEPARATOR . '_autoload.php';
+require_once \SimpleSAML\Utils\Config::getConfigDir() . DIRECTORY_SEPARATOR . 'config.php';
 
 # Iterate through configured metadata sources and ensure
 # that a PDO source exists.
@@ -13,14 +13,15 @@ foreach ($config['metadata.sources'] as $s) {
         $mdshp = new \SimpleSAML\Metadata\MetaDataStorageHandlerPdo($s);
         $mdshp->initDatabase();
 
-        foreach (glob("metadata/*.php") as $filename) {
+        $metadataDir = rtrim(\SimpleSAML\Configuration::getInstance()->getString('metadatadir'), '/');
+        foreach (glob("{$metadataDir}/*.php") as $filename) {
             $metadata = [];
             require_once $filename;
             $set = basename($filename, ".php");
-            echo "importing set '$set'...".PHP_EOL;
+            echo "importing set '$set'..." . PHP_EOL;
 
             foreach ($metadata as $k => $v) {
-                echo "\t$k".PHP_EOL;
+                echo "\t$k" . PHP_EOL;
                 $mdshp->addEntry($k, $set, $v);
             }
         }
