@@ -2,12 +2,14 @@
 
 namespace SimpleSAML\Auth;
 
+use SimpleSAML\Configuration;
+use SimpleSAML\Session;
+
 /**
  * Factory class to get instances of \SimpleSAML\Auth\Simple for a given authentication source.
  */
 class AuthenticationFactory
 {
-
     /** @var \SimpleSAML\Configuration */
     protected $config;
 
@@ -15,7 +17,7 @@ class AuthenticationFactory
     protected $session;
 
 
-    public function __construct(\SimpleSAML\Configuration $config, \SimpleSAML\Session $session)
+    public function __construct(Configuration $config, Session $session)
     {
         $this->config = $config;
         $this->session = $session;
@@ -34,4 +36,4 @@ class AuthenticationFactory
     {
         return new Simple($as, $this->config, $this->session);
     }
-}
\ No newline at end of file
+}
