@@ -2,6 +2,12 @@
 
 namespace SimpleSAML\Auth;
 
+use SimpleSAML\Configuration;
+use SimpleSAML\Error;
+use SimpleSAML\Logger;
+use SimpleSAML\Module;
+use SimpleSAML\Utils;
+
 /**
  * Class for implementing authentication processing chains for IdPs.
  *
@@ -46,6 +52,7 @@ class ProcessingChain
      *
      * @param array $idpMetadata  The metadata for the IdP.
      * @param array $spMetadata  The metadata for the SP.
+     * @param string $mode
      */
     public function __construct($idpMetadata, $spMetadata, $mode = 'idp')
     {
@@ -54,8 +61,8 @@ class ProcessingChain
 
         $this->filters = [];
 
-        $config = \SimpleSAML\Configuration::getInstance();
-        $configauthproc = $config->getArray('authproc.'.$mode, null);
+        $config = Configuration::getInstance();
+        $configauthproc = $config->getArray('authproc.' . $mode, null);
 
         if (!empty($configauthproc)) {
             $configfilters = self::parseFilterList($configauthproc);
@@ -72,8 +79,8 @@ class ProcessingChain
             self::addFilters($this->filters, $spFilters);
         }
 
-        \SimpleSAML\Logger::debug('Filter config for '.$idpMetadata['entityid'].'->'.
-            $spMetadata['entityid'].': '.str_replace("\n", '', var_export($this->filters, true)));
+        Logger::debug('Filter config for ' . $idpMetadata['entityid'] . '->' .
+            $spMetadata['entityid'] . ': ' . str_replace("\n", '', var_export($this->filters, true)));
     }
 
 
@@ -84,6 +91,7 @@ class ProcessingChain
      *
      * @param array &$target  Target filter list. This list must be sorted.
      * @param array $src  Source filters. May be unsorted.
+     * @return void
      */
     private static function addFilters(&$target, $src)
     {
@@ -124,7 +132,7 @@ class ProcessingChain
             }
 
             if (!is_array($filter)) {
-                throw new \Exception('Invalid authentication processing filter configuration: '.
+                throw new \Exception('Invalid authentication processing filter configuration: ' .
                     'One of the filters wasn\'t a string or an array.');
             }
 
@@ -141,7 +149,7 @@ class ProcessingChain
      * @param array $config      Array with the authentication processing filter configuration.
      * @param int $priority      The priority of the current filter, (not included in the filter
      *                           definition.)
-     * @return ProcessingFilter  The parsed filter.
+     * @return \SimpleSAML\Auth\ProcessingFilter  The parsed filter.
      */
     private static function parseFilter($config, $priority)
     {
@@ -151,13 +159,15 @@ class ProcessingChain
             throw new \Exception('Authentication processing filter without name given.');
         }
 
-        $className = \SimpleSAML\Module::resolveClass(
+        $className = Module::resolveClass(
             $config['class'],
             'Auth\Process',
             '\SimpleSAML\Auth\ProcessingFilter'
         );
         $config['%priority'] = $priority;
         unset($config['class']);
+
+        /** @var \SimpleSAML\Auth\ProcessingFilter */
         return new $className($config, null);
     }
 
@@ -181,6 +191,9 @@ class ProcessingChain
      * @see State::EXCEPTION_HANDLER_FUNC
      *
      * @param array &$state  The state we are processing.
+     * @throws \SimpleSAML\Error\Exception
+     * @throws \SimpleSAML\Error\UnserializableException
+     * @return void
      */
     public function processState(&$state)
     {
@@ -201,7 +214,7 @@ class ProcessingChain
                 $filter = array_shift($state[self::FILTERS_INDEX]);
                 $filter->process($state);
             }
-        } catch (\SimpleSAML\Error\Exception $e) {
+        } catch (Error\Exception $e) {
             // No need to convert the exception
             throw $e;
         } catch (\Exception $e) {
@@ -209,7 +222,7 @@ class ProcessingChain
              * To be consistent with the exception we return after an redirect,
              * we convert this exception before returning it.
              */
-            throw new \SimpleSAML\Error\UnserializableException($e);
+            throw new Error\UnserializableException($e);
         }
 
         // Completed
@@ -226,6 +239,7 @@ class ProcessingChain
      * to whatever exception handler is defined in the state array.
      *
      * @param array $state  The state we are processing.
+     * @return void
      */
     public static function resumeProcessing($state)
     {
@@ -235,10 +249,10 @@ class ProcessingChain
             $filter = array_shift($state[self::FILTERS_INDEX]);
             try {
                 $filter->process($state);
-            } catch (\SimpleSAML\Error\Exception $e) {
+            } catch (Error\Exception $e) {
                 State::throwException($state, $e);
             } catch (\Exception $e) {
-                $e = new \SimpleSAML\Error\UnserializableException($e);
+                $e = new Error\UnserializableException($e);
                 State::throwException($state, $e);
             }
         }
@@ -255,7 +269,7 @@ class ProcessingChain
              * in $state['ReturnURL'].
              */
             $id = State::saveState($state, self::COMPLETED_STAGE);
-            \SimpleSAML\Utils\HTTP::redirectTrustedURL($state['ReturnURL'], [self::AUTHPARAM => $id]);
+            Utils\HTTP::redirectTrustedURL($state['ReturnURL'], [self::AUTHPARAM => $id]);
         } else {
             /* Pass the state to the function defined in $state['ReturnCall']. */
 
@@ -280,6 +294,7 @@ class ProcessingChain
      * This function will only return if processing completes.
      *
      * @param array &$state  The state we are processing.
+     * @return void
      */
     public function processStatePassive(&$state)
     {
@@ -302,10 +317,10 @@ class ProcessingChain
             $filter = array_shift($state[self::FILTERS_INDEX]);
             try {
                 $filter->process($state);
-            } catch (\SimpleSAML\Error\NoPassive $e) {
+            } catch (Error\NoPassive $e) {
                 // @deprecated will be removed in 2.0
                 // Ignore \SimpleSAML\Error\NoPassive exceptions
-            } catch (\SimpleSAML\Module\saml\Error\NoPassive $e) {
+            } catch (Module\saml\Error\NoPassive $e) {
                 // Ignore \SimpleSAML\Module\saml\Error\NoPassive exceptions
             }
         }
@@ -316,7 +331,7 @@ class ProcessingChain
      *
      * @param string $id The state identifier.
      * @see State::parseStateID()
-     * @return array The state referenced by the $id parameter.
+     * @return array|null The state referenced by the $id parameter.
      */
     public static function fetchProcessedState($id)
     {
@@ -328,6 +343,8 @@ class ProcessingChain
 
     /**
      * @deprecated This method will be removed in SSP 2.0.
+     * @param array &$state
+     * @return void
      */
     private static function addUserID(&$state)
     {
@@ -336,10 +353,10 @@ class ProcessingChain
 
         if (isset($state['Destination']['userid.attribute'])) {
             $attributeName = $state['Destination']['userid.attribute'];
-            \SimpleSAML\Logger::debug("The 'userid.attribute' option has been deprecated.");
+            Logger::debug("The 'userid.attribute' option has been deprecated.");
         } elseif (isset($state['Source']['userid.attribute'])) {
             $attributeName = $state['Source']['userid.attribute'];
-            \SimpleSAML\Logger::debug("The 'userid.attribute' option has been deprecated.");
+            Logger::debug("The 'userid.attribute' option has been deprecated.");
         } else {
             // Default attribute
             $attributeName = 'eduPersonPrincipalName';
@@ -351,12 +368,12 @@ class ProcessingChain
 
         $uid = $state['Attributes'][$attributeName];
         if (count($uid) === 0) {
-            \SimpleSAML\Logger::warning('Empty user id attribute ['.$attributeName.'].');
+            Logger::warning('Empty user id attribute [' . $attributeName . '].');
             return;
         }
 
         if (count($uid) > 1) {
-            \SimpleSAML\Logger::warning('Multiple attribute values for user id attribute ['.$attributeName.'].');
+            Logger::warning('Multiple attribute values for user id attribute [' . $attributeName . '].');
             return;
         }
 
@@ -364,7 +381,7 @@ class ProcessingChain
         $uid = $uid[0];
 
         if (empty($uid)) {
-            \SimpleSAML\Logger::warning('Empty value in attribute '.$attributeName.". on user. Cannot set UserID.");
+            Logger::warning('Empty value in attribute ' . $attributeName . ". on user. Cannot set UserID.");
             return;
         }
         $state['UserID'] = $uid;
