@@ -2,14 +2,12 @@
 
 namespace SimpleSAML\Auth;
 
-use SimpleSAML_Auth_Source;
-
 interface SourceFactory
 {
     /**
      * @param array $info
      * @param array $config
-     * @return SimpleSAML_Auth_Source
+     * @return Source
      */
     public function create(array $info, array $config);
 }
