@@ -30,7 +30,7 @@ class Assertion extends Exception
     {
         assert($assertion === null || is_string($assertion));
 
-        $msg = 'Assertion failed: '.var_export($assertion, true);
+        $msg = 'Assertion failed: ' . var_export($assertion, true);
         parent::__construct($msg);
 
         $this->assertion = $assertion;
@@ -53,13 +53,14 @@ class Assertion extends Exception
      *
      * This function will register this assertion handler. If will not enable assertions if they are
      * disabled.
+     * @return void
      */
     public static function installHandler()
     {
 
         assert_options(ASSERT_WARNING, 0);
         assert_options(ASSERT_QUIET_EVAL, 0);
-        assert_options(ASSERT_CALLBACK, ['\SimpleSAML\Error\Assertion', 'onAssertion']);
+        assert_options(ASSERT_CALLBACK, [Assertion::class, 'onAssertion']);
     }
 
 
@@ -71,6 +72,7 @@ class Assertion extends Exception
      * @param string $file  The file assert was called from.
      * @param int $line  The line assert was called from.
      * @param mixed $message  The expression which was passed to the assert-function.
+     * @return void
      */
     public static function onAssertion($file, $line, $message)
     {
