@@ -1,4 +1,7 @@
 <?php
+
+namespace SimpleSAML\Error;
+
 /**
  * Exception indicating illegal innput from user.
  *
@@ -6,7 +9,7 @@
  * @package SimpleSAMLphp_base
  *
  */
-class SimpleSAML_Error_BadUserInput extends SimpleSAML_Error_User
-{
 
+class BadUserInput extends User
+{
 }
