@@ -1,4 +1,7 @@
 <?php
+
+namespace SimpleSAML\Error;
+
 /**
  * Exception indicating wrong password given by user.
  *
@@ -6,7 +9,7 @@
  * @package SimpleSAMLphp_base
  *
  */
-class SimpleSAML_Error_InvalidCredential extends SimpleSAML_Error_User
-{
 
+class InvalidCredential extends User
+{
 }
