@@ -1,15 +1,16 @@
 <?php
 
+namespace SimpleSAML\Error;
 
 /**
- * Class SimpleSAML_Error_ProxyCountExceeded
+ * Class ProxyCountExceeded
  *
  * @deprecated This class has been deprecated and will be removed in SimpleSAMLphp 2.0. Please use
- * SimpleSAML\Module\saml\Error\ProxyCountExceeded instead.
+ * \SimpleSAML\Module\saml\Error\ProxyCountExceeded instead.
  *
  * @see \SimpleSAML\Module\saml\Error\ProxyCountExceeded
  */
-class SimpleSAML_Error_ProxyCountExceeded extends SimpleSAML_Error_Exception
-{
 
+class ProxyCountExceeded extends Exception
+{
 }
