@@ -1,5 +1,7 @@
 <?php
 
+namespace SimpleSAML\Error;
+
 /**
  * Baseclass for user error exceptions
  *
@@ -8,7 +10,7 @@
  * @package SimpleSAMLphp_base
  *
  */
-class SimpleSAML_Error_User extends SimpleSAML_Error_Exception
-{
 
+class User extends Exception
+{
 }
