@@ -1,5 +1,7 @@
 <?php
 
+namespace SimpleSAML\Error;
+
 /**
  * Exception indicating user not found by authsource.
  *
@@ -7,7 +9,7 @@
  * @package SimpleSAMLphp_base
  *
  */
-class SimpleSAML_Error_UserNotFound extends SimpleSAML_Error_User
-{
 
+class UserNotFound extends User
+{
 }
